@@ -1,38 +1,41 @@
 #ifndef config_def_h_INCLUDED
 #define config_def_h_INCLUDED
 
-static const char *default_font = "Monospace 14";
-static const int transparency = 225;
+#define DEFAULT_FONT "Sans 14"
+static const int transparency = 255;
 
-struct clr_scheme scheme = {
+struct clr_scheme schemes[] = {
+{
   /* colors */
   .bg = {.bgra = {15, 15, 15, transparency}},
   .fg = {.bgra = {45, 45, 45, transparency}},
   .high = {.bgra = {100, 100, 100, transparency}},
   .swipe = {.bgra = {100, 255, 100, 64}},
   .text = {.color = UINT32_MAX},
-};
-struct clr_scheme scheme1 = {
+  .font = DEFAULT_FONT,
+},
+{
   /* colors */
   .bg = {.bgra = {15, 15, 15, transparency}},
   .fg = {.bgra = {32, 32, 32, transparency}},
   .high = {.bgra = {100, 100, 100, transparency}},
   .swipe = {.bgra = {100, 255, 100, 64}},
   .text = {.color = UINT32_MAX},
+  .font = DEFAULT_FONT,
+}
 };
 
 /* layers is an ordered list of layouts, used to cycle through */
 static enum layout_id layers[] = {
   Full, // First layout is the default layout on startup
-  Special,   Emoji,  Simple,  SimpleGrid, Nav,      Dialer,
-  Cyrillic,  Arabic, Persian, Greek,      Georgian,
+  Special, 
   NumLayouts // signals the last item, may not be omitted
 };
 
 /* layers is an ordered list of layouts, used to cycle through */
 static enum layout_id landscape_layers[] = {
   Landscape, // First layout is the default layout on startup
-  Special,   Emoji, Nav, Greek,
+  LandscapeSpecial,
   NumLayouts // signals the last item, may not be omitted
 };
 
