@@ -6,10 +6,10 @@
 
 struct drw {
 	struct wl_shm *shm;
-	PangoFontDescription *font_description;
 };
 struct drwsurf {
-	uint32_t width, height, scale, size;
+	uint32_t width, height, size;
+	double scale;
 
 	struct drw *ctx;
 	struct wl_surface *surf;
@@ -22,7 +22,7 @@ struct drwsurf {
 };
 struct kbd;
 
-void drwsurf_resize(struct drwsurf *ds, uint32_t w, uint32_t h, uint32_t s);
+void drwsurf_resize(struct drwsurf *ds, uint32_t w, uint32_t h, double s);
 void drwsurf_flip(struct drwsurf *ds);
 
 typedef union {
@@ -30,6 +30,8 @@ typedef union {
 	uint32_t color;
 } Color;
 
+void drw_do_clear(struct drwsurf *d, uint32_t x, uint32_t y,
+                      uint32_t w, uint32_t h);
 void drw_do_rectangle(struct drwsurf *d, Color color, uint32_t x, uint32_t y,
                       uint32_t w, uint32_t h, bool fill);
 void drw_fill_rectangle(struct drwsurf *d, Color color, uint32_t x, uint32_t y,
@@ -38,7 +40,8 @@ void drw_over_rectangle(struct drwsurf *d, Color color, uint32_t x, uint32_t y,
                         uint32_t w, uint32_t h);
 
 void drw_draw_text(struct drwsurf *d, Color color, uint32_t x, uint32_t y,
-                   uint32_t w, uint32_t h, const char *label);
+                   uint32_t w, uint32_t h, uint32_t b, const char *label,
+                   PangoFontDescription *font_description);
 
 uint32_t setup_buffer(struct drwsurf *drwsurf);
 
