@@ -42,7 +42,8 @@ enum key_modifier_type {
 };
 
 enum key_draw_type {
-	Unpress = 0,
+	None = 0,
+	Unpress,
 	Press,
 	Swipe,
 };
@@ -53,6 +54,8 @@ struct clr_scheme {
 	Color high;
 	Color swipe;
 	Color text;
+	char *font;
+	PangoFontDescription *font_description;
 };
 
 struct key {
@@ -81,6 +84,7 @@ struct layout {
 	struct key *keys;
 	const char *keymap_name;
 	const char *name;
+	bool abc; //is this an alphabetical/abjad layout or not? (i.e. something that is a primary input layout)
 	uint32_t keyheight; // absolute height (pixels)
 };
 
@@ -88,26 +92,32 @@ struct kbd {
 	bool debug;
 
 	struct layout *layout;
-	struct clr_scheme scheme;
-	struct clr_scheme scheme1;
+	struct clr_scheme *schemes;
 
 	bool print;
 	bool print_intersect;
-	uint32_t w, h, s;
+	uint32_t w, h;
+	double scale;
+	double preferred_scale, preferred_fractional_scale;
 	bool landscape;
 	uint8_t mods;
 	uint8_t compose;
 	struct key *last_press;
 	struct key *last_swipe;
-	struct layout *prevlayout;
+	struct layout *prevlayout; //the previous layout, needed to keep track of keymap changes
 	size_t layer_index;
+	struct layout *last_abc_layout; //the last alphabetical layout to fall back to (may be further away than prevlayout)
+	size_t last_abc_index; //the layer index of the last alphabetical layout
 
 	struct layout *layouts;
 	enum layout_id *layers;
 	enum layout_id *landscape_layers;
 
 	struct drwsurf *surf;
+	struct drwsurf *popup_surf;
 	struct zwp_virtual_keyboard_v1 *vkbd;
+
+	uint32_t last_popup_x, last_popup_y, last_popup_w, last_popup_h;
 };
 
 void draw_inset(struct drwsurf *ds, uint32_t x, uint32_t y, uint32_t width,
@@ -119,17 +129,20 @@ void kbd_init(struct kbd *kb, struct layout *layouts,
               char *layer_names_list, char *landscape_layer_names_list);
 void kbd_init_layout(struct layout *l, uint32_t width, uint32_t height);
 struct key *kbd_get_key(struct kbd *kb, uint32_t x, uint32_t y);
+size_t kbd_get_layer_index(struct kbd *kb, struct layout *l);
 void kbd_unpress_key(struct kbd *kb, uint32_t time);
 void kbd_release_key(struct kbd *kb, uint32_t time);
 void kbd_motion_key(struct kbd *kb, uint32_t time, uint32_t x, uint32_t y);
 void kbd_press_key(struct kbd *kb, struct key *k, uint32_t time);
 void kbd_print_key_stdout(struct kbd *kb, struct key *k);
+void kbd_clear_last_popup(struct kbd *kb);
 void kbd_draw_key(struct kbd *kb, struct key *k, enum key_draw_type);
 void kbd_draw_layout(struct kbd *kb);
 void kbd_resize(struct kbd *kb, struct layout *layouts, uint8_t layoutcount);
 uint8_t kbd_get_rows(struct layout *l);
 double kbd_get_row_length(struct key *k);
-void kbd_switch_layout(struct kbd *kb, struct layout *l);
+void kbd_next_layer(struct kbd *kb, struct key *k, bool invert);
+void kbd_switch_layout(struct kbd *kb, struct layout *l, size_t layer_index);
 
 void create_and_upload_keymap(struct kbd *kb, const char *name,
                               uint32_t comp_unichr, uint32_t comp_shift_unichr);
